==> classpath-0.15.tar.gz: classpath-0.15/gnu/xml/libxmlj/dom/GnomeDocumentType.java <==
/* GnomeDocumentType.java - 
   Copyright (C) 2004 Free Software Foundation, Inc.

This file is part of GNU Classpath.

GNU Classpath is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

GNU Classpath is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with GNU Classpath; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
02111-1307 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version. */

package gnu.xml.libxmlj.dom;

import org.w3c.dom.DocumentType;
import org.w3c.dom.NamedNodeMap;

/**
 * A DOM document type node implemented in libxml2.
 *
 * @author <a href='mailto:dog@gnu.org'>Chris Burdess</a>
 */
class GnomeDocumentType
extends GnomeNode
implements DocumentType
{

  GnomeDocumentType (Object id)
  {
    super (id);
  }
  
  public String getName ()
  {
    return getNodeName ();
  }

  public NamedNodeMap getEntities ()
  {
    return new GnomeNamedNodeMap (id, 1);
  }

  public NamedNodeMap getNotations ()
  {
    return new GnomeNamedNodeMap (id, 2);
  }

  public native String getPublicId ();

  public native String getSystemId ();

  public native String getInternalSubset ();

  public String toString ()
  {
    String publicId = getPublicId ();
    StringBuffer buffer = new StringBuffer (getClass ().getName ());
    buffer.append ("[");
    if (publicId != null)
      {
        buffer.append ("publicId=");
        buffer.append (publicId);
        buffer.append (",");
      }
    buffer.append ("systemId=");
    buffer.append (getSystemId ());
    buffer.append ("]");
    return buffer.toString ();
  }

}

==> classpath-0.96.tar.gz: classpath-0.96/gnu/xml/libxmlj/dom/GnomeDocumentType.java <==
/* GnomeDocumentType.java - 
   Copyright (C) 2004 Free Software Foundation, Inc.

This file is part of GNU Classpath.

GNU Classpath is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

GNU Classpath is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with GNU Classpath; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version. */

package gnu.xml.libxmlj.dom;

import org.w3c.dom.DocumentType;
import org.w3c.dom.NamedNodeMap;

/**
 * A DOM document type node implemented in libxml2.
 *
 * @author <a href='mailto:dog@gnu.org'>Chris Burdess</a>
 */
class GnomeDocumentType
extends GnomeNode
implements DocumentType
{

  GnomeDocumentType (Object id)
  {
    super (id);
  }
  
  public String getName ()
  {
    return getNodeName ();
  }

  public NamedNodeMap getEntities ()
  {
    return new GnomeNamedNodeMap (id, 1);
  }

  public NamedNodeMap getNotations ()
  {
    return new GnomeNamedNodeMap (id, 2);
  }

  public native String getPublicId ();

  public native String getSystemId ();

  public native String getInternalSubset ();

  public String toString ()
  {
    String publicId = getPublicId ();
    StringBuffer buffer = new StringBuffer (getClass ().getName ());
    buffer.append ("[");
    if (publicId != null)
      {
        buffer.append ("publicId=");
        buffer.append (publicId);
        buffer.append (",");
      }
    buffer.append ("systemId=");
    buffer.append (getSystemId ());
    buffer.append ("]");
    return buffer.toString ();
  }

}
